@@ -1,5 +1,10 @@
 #' @title NetVis
-#' @param input_vis Network to be plotted. It's usually an output from the wTO.Complete or Consensus.
+#' @param Node.1 Names of the Nodes.1 that are connected to the Nodes.2. It's the output from wTO.Complete or Consensus.
+#' @param Node.2 Names of the Nodes.2 that are connected to the Nodes.1. It's the output from wTO.Complete or Consensus.
+#' @param wTO weight of the links, the wTO output from wTO.Complete or wTO.Consensus.
+#' @param pval p-values for the wTO value. By default it is NULL.
+#' @param padj Adjusted p-values for the wTO value. By default it is NULL.
+
 #' @param cutoff It's a list containing the kind of cutoff to be used (pval, Threshold or pval.adj)and it's value. Example: cutoff= list(kind = "Threshold", value = 0.5)
 #' @param layout a layout from the igraph package.
 #' @param smooth.edges If the edges should be smoothed or not.
@@ -12,38 +17,47 @@
 #' @importFrom  visNetwork visNetwork visInteraction visEdges visOptions visClusteringByGroup visLegend visPhysics visIgraphLayout visOptions visSave
 #' @importFrom plyr arrange join
 #' @importFrom igraph graph_from_data_frame degree E
+#' @importFrom data.table as.data.table
 #' @importFrom  magrittr "%>%"
 #'
 #' @export
 #'
 #' @examples
 #'
-#'  EXAMPLE =  wTO.Complete( k =2, n = 10, Data = ExampledfExpression,
+#'  X =  wTO.Complete( k =2, n = 8, Data = ExampledfExpression,
 #'  Overlap = ExampleGRF$x, method = "p")
 #' # Plot with the default aguments.
-#'  x = NetVis(EXAMPLE$wTO, cutoff= list(kind = "Threshold", value = 0.5))
-#'  x$network
+#'  NetVis(Node.1 = X$wTO$Node.1, Node.2 = X$wTO$Node.2, 
+#'  wTO = X$wTO$wTO_sign, pval = X$wTO$pval_sign, 
+#'  padj = X$wTO$pval_sign)
 #'
 #'\dontrun{
 #' # Plotting just the edges with p-value < 0.05, with straight edges, nodes clustered,
 #' # no legend and mapipulation of the graph enabled.
-#'  x = NetVis(EXAMPLE$wTO, cutoff= list(kind = "pval", value = 0.05),
+#'   NetVis(Node.1 = X$wTO$Node.1, Node.2 = X$wTO$Node.2, 
+#'  wTO = X$wTO$wTO_sign, pval = X$wTO$pval_sign, 
+#'  padj = X$wTO$pval_sign,
+#'   cutoff= list(kind = "pval", value = 0.05),
 #'   smooth.edges = FALSE,
 #'  Cluster = TRUE, legend = FALSE, manipulation = TRUE)
 #' # Plotting just the edges with wTO > 0.50, no legend and the nodes:
 #' # "ZNF738", "ZNF677" with triagle shape,
 #' # no legend and mapipulation of the graph enabled.
-#'  x = NetVis(EXAMPLE$wTO, cutoff= list(kind = "Threshold", value = 0.5),legend = FALSE,
+#'  NetVis(Node.1 = X$wTO$Node.1, Node.2 = X$wTO$Node.2, 
+#'  wTO = X$wTO$wTO_sign, pval = X$wTO$pval_sign, 
+#'  padj = X$wTO$pval_sign, cutoff= list(kind = "Threshold", value = 0.5),legend = FALSE,
 #'  shape = list(shape = "triangle", names = c("ZNF738", "ZNF677")))
-#'  x$network
+#'  
 #'  }
 
 
 
-NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
-                         layout = NULL, smooth.edges = T, path = NULL, Cluster = F,
-                         legend = T, shape=list(shape = "triangle", names= NULL), manipulation = F)
+NetVis = function (Node.1, Node.2, wTO, pval,
+                   padj,  cutoff = list(kind = "Threshold", value = 0.5),
+                   layout = NULL, smooth.edges = T, path = NULL, Cluster = F,
+                   legend = T, shape=list(shape = "triangle", names= NULL), manipulation = F)
 {
+  input_vis = data.frame (Node.1 = Node.1, Node.2 = Node.2, wTO = as.numeric(wTO), pval = pval, padj = padj)
   `%ni%` <- Negate(`%in%`)
   `%>%` <- magrittr::`%>%`
   if (cutoff$kind %ni% c("Threshold", "pval", "pval.adj")) {
@@ -52,21 +66,22 @@ NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
   if (is.numeric(cutoff$value) == F) {
     stop("cutoff value must be numeric.")
   }
-  if (class(input_vis) != "data.frame") {
-    stop("input_vis must be a data.frame.")
-  }
+  # if (class(input_vis) != "data.frame") {
+  #   stop("input_vis must be a data.frame.")
+  # }
   if (Cluster %ni% c(T, F)) {
     stop("Cluster must be T / F.")
   }
   if (smooth.edges %ni% c(T, F)) {
     stop("smooth.edges must be T / F.")
   }
-  if (names(input_vis)[1] != "Node.1") {
-    stop("Name for the first column in input_vis must be \"Node.1\".")
-  }
-  if (names(input_vis)[2] != "Node.2") {
-    stop("Name for the second column in input_vis must be \"Node.2\".")
-  }
+  # if (names(input_vis)[1] != "Node.1") {
+  #   stop("Name for the first column in input_vis must be \"Node.1\".")
+  # }
+  # if (names(input_vis)[2] != "Node.2") {
+  #   stop("Name for the second column in input_vis must be \"Node.2\".")
+  # }
+  input_vis = subset(input_vis, abs(input_vis$wTO) > 0.01)
   if (cutoff$kind == "Threshold") {
     input_vis = subset(input_vis, abs(input_vis$wTO) >= cutoff$value)
   }
@@ -77,7 +92,7 @@ NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
     input_vis = subset(input_vis, input_vis$pval.adj <= cutoff$value)
   }
   if (nrow(input_vis) <= 2) {
-    stop("There is less than 2 nodes on your network. Choose a higher cutoff.")
+    stop("There is less than 2 nodes on your network. Choose a lower cutoff.")
   }
   if (smooth.edges == T) {
     smooth.edges = "enabled"
@@ -94,13 +109,13 @@ NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
   # print(DEGREE)
   # print(nodes)
   nodes = suppressMessages(plyr::join(nodes, DEGREE))
-
+  
   nodes$shape = ifelse(nodes$id %in% shape$names, shape$shape, "dot")
   # print(nodes)
   nodes$value = (nodes$degree - min(nodes$degree))/(max(nodes$degree) -
                                                       min(nodes$degree))
   # print(cbind(nodes$value, nodes$degree))
-
+  
   nodes$value = nodes$value * 2 + 1
   nodes$size = nodes$value
   nodes$group = igraph::edge.betweenness.community(g)$membership
@@ -108,9 +123,9 @@ NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
   # print(nodes)
   # nodes$shape = "circle"
   #
-
+  
   # nodes$value = ifelse(nodes$id %in% shape$names, 3, 1)
-
+  
   nodes$title = paste0("<p> Node ID: ", nodes$id, "<br>Degree: ",
                        nodes$degree, "</p>")
   edges <- data.frame(from = input_vis$Node.1, to = input_vis$Node.2)
@@ -122,14 +137,14 @@ NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
                        "</p>")
   ledges <- data.frame(color = c("violetred", "springgreen"),
                        label = c("+ wTO", "- wTO"), arrows = c("", ""))
-
+  
   network <- visNetwork::visNetwork(nodes, edges) %>%
     visNetwork::visInteraction(navigationButtons = TRUE) %>%
     visNetwork::visEdges(smooth = smooth.edges) %>%
     visNetwork::visOptions(highlightNearest = list(enabled = TRUE,
                                                    degree = 1, hover = T), nodesIdSelection = list(enabled = TRUE,
-                                                  style = "width: 200px; height: 26px;\n   background: #f8f8f8;\n   color: darkblue;\n   border:none;\n   outline:none;"),
-                                                   manipulation = F)  %>%
+                                                                                                   style = "width: 200px; height: 26px;\n   background: #f8f8f8;\n   color: darkblue;\n   border:none;\n   outline:none;"),
+                           manipulation = F)  %>%
     visNetwork::visPhysics(enabled = F)
   if (Cluster == T) {
     network <- network %>% visNetwork::visClusteringByGroup(groups = unique((nodes$group)))
@@ -138,7 +153,7 @@ NetVis = function (input_vis, cutoff = list(kind = "Threshold", value = 0.5),
     network <- network %>% visNetwork::visLegend(width = 0.3,
                                                  position = "right", main = "Group", addEdges = ledges,
                                                  ncol = 2)
-
+    
   }
   if (!is.null(layout)) {
     network <- network %>% visNetwork::visIgraphLayout(layout = layout)
