@@ -9,13 +9,13 @@
 
 
 wTO = function(A,  sign = c("abs", "sign")){
-
+  
   if(sign %in% c("abs", "absolute")){
     A = abs(A)
   }
   A_TF = as.data.frame(subset(A, select = row.names(A)))
   C = as.matrix(A) %*% t(A)
-
+  
   W = C + A_TF ###
   K  = matrix(NA, nrow(A_TF), ncol(A_TF))
   KI = rowSums(abs(A), na.rm = T)
@@ -24,6 +24,6 @@ wTO = function(A,  sign = c("abs", "sign")){
       K[ii,jj] = min(KI[ii], KI[jj])
     }
   }
-  WTO = W / (K + 1 - abs(A_TF))
+  WTO = round(W / (K + 1 - abs(A_TF)),3)
   return(WTO)
 }
